==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Videz grafike</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Barve</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Videz grafike</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>Ozadje:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Kurzor</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translation>Kazalni križec:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Neaktivni kazalni križec:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Izhodišče</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Relativna ničla:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Mreža</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Tabelarična mreža:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Izbor</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Primarna barva izbora:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Uporabi sekundarno barvo izbora</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Sekundarna barva izbora:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Premična referenčna točka:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Rob okvirja izbire:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Polnilo okvirja izbire:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Polnilo navzkrižne izbire:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Snap Tools</source>
        <translation>Orodja lepljenja</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Napis lepljenja:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Orodja informacij</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Mere in napisi:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Orodja risanja</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Pomožne oblike:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Orodja povečave</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Okvir povečave:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translation type="obsolete">Neaktivni kazalni križec:</translation>
    </message>
    <message>
        <location line="-562"/>
        <source>Origin:</source>
        <translation>Izhodišče:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translation type="obsolete">Relativna ničla:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="obsolete">Referenčna točka:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translation>Mreža:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translation type="obsolete">Tabelarična mreža:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translation type="obsolete">Polje za povečavo:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translation type="obsolete">Izbor:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translation type="obsolete">Rob okvirja izbire:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translation type="obsolete">Okvir izbire:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translation type="obsolete">Navzkrižni okvir izbire:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translation type="obsolete">Pomožne oblike:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translation type="obsolete">Ozadje informacijskih napisov:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translation type="obsolete">Pisava informacijskih napisov:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translation type="obsolete">Merilna orodja:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Videz grafike</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Barve</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Videz grafike</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>Ozadje:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Kurzor</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translation>Kazalni križec:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Neaktivni kazalni križec:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Izhodišče</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Relativna ničla:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Mreža</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Tabelarična mreža:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Izbor</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Primarna barva izbora:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Uporabi sekundarno barvo izbora</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Sekundarna barva izbora:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Premična referenčna točka:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Sekundarne referenčne točke:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Rob okvirja izbire:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Polnilo okvirja izbire:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Polnilo navzkrižne izbire:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Start points:</source>
        <translation>Začetne točke:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End points:</source>
        <translation>Končne točke:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Snap Tools</source>
        <translation>Orodja lepljenja</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Napis lepljenja:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Orodja informacij</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Mere in napisi:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Orodja risanja</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Pomožne oblike:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Orodja povečave</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Okvir povečave:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translation type="obsolete">Neaktivni kazalni križec:</translation>
    </message>
    <message>
        <location line="-616"/>
        <source>Origin:</source>
        <translation>Izhodišče:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translation type="obsolete">Relativna ničla:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="obsolete">Referenčna točka:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translation>Mreža:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translation type="obsolete">Tabelarična mreža:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translation type="obsolete">Polje za povečavo:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translation type="obsolete">Izbor:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translation type="obsolete">Rob okvirja izbire:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translation type="obsolete">Okvir izbire:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translation type="obsolete">Navzkrižni okvir izbire:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translation type="obsolete">Pomožne oblike:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translation type="obsolete">Ozadje informacijskih napisov:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translation type="obsolete">Pisava informacijskih napisov:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translation type="obsolete">Merilna orodja:</translation>
    </message>
</context>
</TS>
